Module analyzable

Module analyzable 

Miniscript Analysis

Tools for determining whether the guarantees offered by the library actually hold.

Structs

ExtParams
Params for parsing miniscripts that either non-sane or non-specified(experimental) in the spec. Used as a parameter Miniscript::from_str_ext and Miniscript::parse_with_ext.

Enums

AnalysisError
Possible reasons Miniscript guarantees can fail We currently mark Miniscript as Non-Analyzable if