Module limits

Module limits 

Miscellaneous constraints imposed by Bitcoin. These constraints can be either Consensus or Policy (standardness) rules, for either Segwitv0 or Legacy scripts.

Constants

MAX_BLOCK_WEIGHT
The maximum allowed weight for a block, see BIP 141 (network rule)
MAX_OPS_PER_SCRIPT
Maximum operations per script
MAX_PUBKEYS_PER_MULTISIG
Maximum pubkeys as arguments to CHECKMULTISIG
MAX_SCRIPTSIG_SIZE
Maximum script sig size allowed by standardness rules
MAX_SCRIPT_ELEMENT_SIZE
Maximum script element size allowed by consensus rules
MAX_SCRIPT_SIZE
Maximum script size allowed by consensus rules
MAX_STACK_SIZE
Maximum items during stack execution
MAX_STANDARD_P2WSH_SCRIPT_SIZE
Maximum script size allowed by standardness rules
MAX_STANDARD_P2WSH_STACK_ITEMS
Maximum p2wsh initial stack items