interpreter_check

Function interpreter_check 

pub fn interpreter_check<C: Verification>(
    psbt: &PartiallySignedTransaction,
    secp: &Secp256k1<C>,
) -> Result<(), Error>
Interprets all psbt inputs and checks whether the script is correctly interpreted according to the context The psbt must have included final script sig and final witness. In other words, this checks whether the finalized psbt interprets correctly